package com.fiorano.esb.service.filenamedconfig.swt.ui;

import org.eclipse.swt.SWT;
import org.eclipse.swt.layout.GridData;
import org.eclipse.swt.layout.GridLayout;
import org.eclipse.swt.widgets.Composite;
import org.eclipse.swt.widgets.Label;
import org.eclipse.swt.widgets.Text;

import com.fiorano.esb.server.api.service.config.editorsupport.PropertyEditor;
import com.fiorano.esb.server.api.service.config.editorsupport.ValidationException;
import com.fiorano.esb.server.api.service.config.ui.NamedConfigurationUI;
import com.fiorano.esb.service.filenamedconfig.model.FileConfiguration;
import com.fiorano.services.common.configuration.NamedConfiguration;
import com.fiorano.util.StringUtil;

public class FileConfigurationUI extends NamedConfigurationUI {
	
	private Text directoryText;
	private Text fileText;
	private FileConfiguration configuration;

	@SuppressWarnings("rawtypes")
	public FileConfigurationUI(PropertyEditor editor, Composite parent, int style) {
		super(editor, parent, style);
		buildControls();
	}

	public FileConfigurationUI(String guid, Composite parent, int style) {
		super(parent, style);
		buildControls();
	}

	@Override
	protected boolean validateConfig() throws ValidationException {
		
		if (StringUtil.isEmpty(directoryText.getText()) || StringUtil.isEmpty(fileText.getText())) {
			throw new ValidationException("Directory and FileName are mandatory");
		}
		
		return false;
	}

	@Override
	protected NamedConfiguration updateConfig() {
		
		if (configuration == null) {
			return null;
		}
		
		configuration.setDirectory(directoryText.getText());
		configuration.setFileName(fileText.getText());
		
		return configuration;
	}

	@Override
	protected void updateUI() {
		
		if (configuration == null) {
			return;
		}
		
		if (configuration.getDirectory() != null) {
			directoryText.setText(configuration.getDirectory());
		}
		
		if (configuration.getFileName() != null) {
			fileText.setText(configuration.getFileName());
		}
	}
	
	public void setValue(FileConfiguration config) {
		super.setValue(config);
		this.configuration = config;
		updateValuesToUI();
	}

	protected void buildComponentControls(Composite parent) {
		
		Composite composite = new Composite(parent, SWT.NONE);
		composite.setLayout(new GridLayout(2, false));
		composite.setLayoutData(new GridData(SWT.FILL, SWT.FILL, true, true));
		
		Label directoryLabel = new Label(composite, SWT.NONE);
		directoryLabel.setText("Directory");
		
		directoryText = new Text(composite, SWT.BORDER);
		directoryText.setLayoutData(new GridData(SWT.FILL, SWT.NONE, true, false));
		
		Label fileNameLabel = new Label(composite, SWT.NONE);
		fileNameLabel.setText("File Name");
		
		fileText = new Text(composite, SWT.BORDER);
		fileText.setLayoutData(new GridData(SWT.FILL, SWT.NONE, true, false));
	}
}
